# Sample PySys testcase
# Copyright (c) 2015-2016, 2018, 2020 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors. 
# Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 

import pysys
from pysys.constants import *

class PySysTest(pysys.basetest.BaseTest):

	def execute(self):
		appHome = self.project.appHome + '/connectivity_plugin/java/JSON-Codec'

		# build the sample, putting the results into the testcase output dir
		self.apama.antBuild(appHome + '/build.xml', args=['-Doutput-dir=%s/Release'%self.output])

		# create a correlator
		correlator = self.apama.startCorrelator('correlator', 
			config=[self.input+'/test-config.yaml'], 
			
			# these properties are used within the test .yaml file to specify input/output locations
			configPropertyOverrides={
				'TEST_OUTPUT_DIR': self.output, 
				'TEST_SUBJECT_DIR': appHome,
			})
		correlator.injectEPL([
			self.project.APAMA_HOME+'/monitors/ConnectivityPluginsControl.mon', 
			self.project.APAMA_HOME+'/monitors/ConnectivityPlugins.mon',
			appHome+'/demo/DemoApp.mon',
			])

		# wait until the correlator receives the events (aborting if an error occurs)
		self.waitForGrep('correlator.log', expr="Sending special offer", condition="==2", 
			errorExpr=['( ERROR .*| WARN .*jsonChain.*)'], 
			process=correlator.process)
		
		# wait until 2 messages are received in this file
		self.waitForGrep('specialoffers-output.json.txt', expr="metadata=", condition="==2", errorExpr=[' (ERROR|FATAL) '])
		
	def validate(self):
		# check the received events against the reference 
		appHome = self.project.appHome + '/connectivity_plugin/java/JSON-Codec'
		self.assertDiff('specialoffers-output.json.txt', 'reference-specialoffers-output.json.txt', 
			filedir2=appHome+'/demo')
